Struct Agc1DigEng
#[repr(transparent)]pub struct Agc1DigEng(pub u32);Expand description
AGC1_DIG_ENG register.
Tuple Fields
0: u32Implementations
impl Agc1DigEng
impl Agc1DigEng
pub const fn agc_thr_low_6(&self) -> u8
pub const fn agc_thr_low_6(&self) -> u8
Low threshold for 6dB steps.
pub fn set_agc_thr_low_6(&mut self, val: u8)
pub fn set_agc_thr_low_6(&mut self, val: u8)
Low threshold for 6dB steps.
pub const fn agc_autolock(&self) -> bool
pub const fn agc_autolock(&self) -> bool
AGC locks when level is steady between high threshold and lock threshold.
pub fn set_agc_autolock(&mut self, val: bool)
pub fn set_agc_autolock(&mut self, val: bool)
AGC locks when level is steady between high threshold and lock threshold.
pub const fn agc_lock_sync(&self) -> bool
pub const fn agc_lock_sync(&self) -> bool
AGC locks when Access Address is detected (recommended).
pub fn set_agc_lock_sync(&mut self, val: bool)
pub fn set_agc_lock_sync(&mut self, val: bool)
AGC locks when Access Address is detected (recommended).