Struct DemModDigUsr
#[repr(transparent)]pub struct DemModDigUsr(pub u32);Expand description
DEM_MOD_DIG_USR register.
Tuple Fields
0: u32Implementations
impl DemModDigUsr
impl DemModDigUsr
pub const fn channel_num(&self) -> u8
pub const fn channel_num(&self) -> u8
Index for internal lock up table in which the synthesizer setup is contained.
pub fn set_channel_num(&mut self, val: u8)
pub fn set_channel_num(&mut self, val: u8)
Index for internal lock up table in which the synthesizer setup is contained.